/* Program written by Craig Aubuchon in Spring 2010 */

/* This program calculates correlation measures between number (and rate) of bank failures
    to measures of local economic conditions. */


LIBNAME fail "C:\h1cpa01\work\Current Wheelock\Active\Bank Failures" ;
OPTIONS PS = 60 LS = 75 CENTER PAGENO = 1 ;


/* First step is to merge the correlation variables to the measures of failure rates */
/* note: map_panel is created as a merge of map_panel1986 and map_panel2006 by state code.  
         This is done in program number 4 - maps_4          */

proc sort data = fail.map_panel;
  by state_abr;
run;
proc sort data = fail.correlation_variables;
  by state;
run;

DATA fail.correl;
  MERGE fail.correlation_variables fail.map_panel (rename=(state_abr=state));
  BY state;
RUN;

ODS OUTPUT pearsoncorr = corr_yr1986;
PROC CORR data = fail.correl;
 Title1 'Correlation Measures in 1980s';
 WITH hpi_chg82_87 hpi_chg87_92 unemp_chg86_92 loan_chg82_86 all_chg86_92 pci_chg86_92 gdp_chg86_92 restrict86;
 VAR nfail_1992 failrt_86 dep_failrt86;
RUN;

ODS OUTPUT pearsoncorr = corr_yr2006;
PROC CORR data = fail.correl;
 Title1 'Correlation Measures in 2000s';
 WITH hpi_chg03_07 hpi_chg07_09 unemp_chg06_09 loan_chg02_06 subratio06 sub_chg03_06 all_chg07_09 pci_chg06_09 gdp_chg06_08 bbq_chg07_09 restrict06	;
 VAR nfail_2010 failrt_06 dep_failrt06;
RUN;

ODS OUTPUT pearsoncorr = corrfull_yr2006 ;
PROC CORR data = fail.correl;
 Title1 'Correlation Measures in 2000s';
 VAR hpi_chg03_07 hpi_chg07_09 loan_chg02_06 subratio06 sub_chg03_06 all_chg07_09 unemp_chg06_09 pci_chg06_09 gdp_chg06_08 bbq_chg07_09 restrict06	;
RUN;

ODS OUTPUT pearsoncorr = corr_yr2006exclnevada;
PROC CORR data = fail.correl;
 Title1 'Correlation Measures in 2000s, excluding Nevada';
 WITH hpi_chg03_07 hpi_chg07_09 unemp_chg06_09 loan_chg02_06 all_chg06_09 all_chg07_09 pci_chg06_09 gdp_chg06_08 bbq_chg07_09 restrict06	;
 VAR nfail_2010 failrt_06 dep_failrt06;
 WHERE state_cd ~= 32;
RUN;

/* Export Correlation Data:
PROC EXPORT DATA= work.corr_yr1986 
            OUTFILE= "C:\h1cpa01\work\Current Wheelock\Active\Bank Failures\Failures Correlation.xls" 
            DBMS=EXCEL REPLACE;
     SHEET="1986"; 
RUN;
PROC EXPORT DATA= work.corr_yr2006 
            OUTFILE= "C:\h1cpa01\work\Current Wheelock\Active\Bank Failures\Failures Correlation.xls" 
            DBMS=EXCEL REPLACE;
     SHEET="2006"; 
RUN;
PROC EXPORT DATA= work.corrfull_yr2006 
            OUTFILE= "C:\h1cpa01\work\Current Wheelock\Active\Bank Failures\Failures Correlation.xls" 
            DBMS=EXCEL REPLACE;
     SHEET="2006full"; 
RUN;
PROC EXPORT DATA= work.corr_yr2006exclnevada 
            OUTFILE= "C:\h1cpa01\work\Current Wheelock\Active\Bank Failures\Failures Correlation.xls" 
            DBMS=EXCEL REPLACE;
     SHEET="2006exclNV"; 
RUN;

*/


/* Sort data by house prices and find states with high unemployment/large decline in GDP */

proc sort data = fail.correl;
  by pci_chg06_09;
run;

proc print data = fail.correl (obs = 10);
  title1 'Data sorted by PCI';
  var state failrt_06 dep_failrt06 hpi_chg07_09 gdp_chg06_08 unemp_chg06_09 pci_chg06_09;
run;

proc sort data = fail.correl;
  by hpi_chg07_09;
run;

proc print data = fail.correl (obs = 10);
  title1 'Data sorted by HPI';
  var state failrt_06 dep_failrt06 hpi_chg07_09 gdp_chg06_08 unemp_chg06_09 pci_chg06_09;
run;

proc sort data = fail.correl;
  by gdp_chg06_08;
run;

proc print data = fail.correl (obs = 10);
  title1 'Data sorted by GDP';
  var state failrt_06 dep_failrt06 hpi_chg07_09 gdp_chg06_08 unemp_chg06_09 pci_chg06_09;
run;
