/* Code written by Craig Aubuchon in April 2010

   Descriptive Statistics for all banks and failed banks during the 2007-2010 sample 

*/


OPTIONS LS = 75 PS = 60 NOCENTER PAGENO = 1 SYMBOLGEN MCOMPILENOTE = ALL MLOGIC;

/* A note on options: symbolgen specifies that log messages about macro variable references will be displayed
					  mcompilenote specifies that a note be completed for all macro compilations
					  mlogic specifies that messages about a macro action are printed to log during execution 
*/

LIBNAME desc            "C:\h1cpa01\work\Current Wheelock\Active\Bank Failures\Descriptive Statistics";
LIBNAME fail            "C:\h1cpa01\work\Current Wheelock\Active\Bank Failures";


/* Descriptive Statistics of the full sample of Banks in the year 2006 
    That satisfy our criteria - charter code (200,300,310) and Bnk Type Analysis code = 0    */

PROC MEANS data = fail.panel2006 n mean min max std q1 median q3;
  Title1 'Descriptive Stats of All Banks 2007-10 with Q2.2006 SOD Data';
  VAR asset depdom totbr tot_zipbr tot_cntybr tot_statebr ;
RUN;
PROC MEANS data = fail.panel2006 n mean min max std q1 median q3;
  Title1 'Descriptive Stats of Failed Banks 2007-10 with Q2.2006 SOD Data';
  VAR asset depdom totbr tot_zipbr tot_cntybr tot_statebr ;
  CLASS fail ; 
  OUTPUT OUT= desc.desc_stats2006 ;
RUN;

/*
PROC EXPORT DATA= desc.desc_stats2006 
            OUTFILE= "C:\h1cpa01\work\Current Wheelock\Active\Bank Failures\Failures_Summary.xls" 
            DBMS=EXCEL REPLACE;
     SHEET="2006allbnkdescstat"; 
RUN;
*/

PROC MEANS data = fail.panel2006 n mean min max std q1 median q3;
  Title1 'Descriptive Stats of Failed Banks 2007-10 with Q2.2006 SOD Data';
  VAR asset depdom totbr tot_zipbr tot_cntybr tot_statebr ;
  WHERE fail = 1; 
  CLASS save;
  OUTPUT OUT= desc.fail_type;
RUN;
/*
PROC EXPORT DATA= desc.fail_type
            OUTFILE= "C:\h1cpa01\work\Current Wheelock\Active\Bank Failures\Failures_Summary.xls" 
            DBMS=EXCEL REPLACE;
     SHEET="06FailBnktype"; 
RUN;
*/

PROC MEANS data = fail.panel2006 n mean min max std q1 median q3;
  Title1 'Descriptive Stats of Surviving Banks 2007-10 with Q2.2006 SOD Data';
  VAR asset depdom totbr tot_zipbr tot_cntybr tot_statebr ;
  WHERE fail ~= 1; 
  CLASS save;
  OUTPUT OUT= desc.nofail_type;
RUN;
/*
PROC EXPORT DATA= desc.nofail_type
            OUTFILE= "C:\h1cpa01\work\Current Wheelock\Active\Bank Failures\Failures_Summary.xls" 
            DBMS=EXCEL REPLACE;
     SHEET="06NofailBnktype"; 
RUN;
*/

PROC MEANS data = fail.panel2006 n mean min max std q1 median q3;
  Title1 'Descriptive Stats of Surviving Banks 2007-10 with Q2.2006 SOD Data';
  VAR asset depdom totbr tot_zipbr tot_cntybr tot_statebr ;
  WHERE fail = 1; 
  CLASS chtr_type_cd;
  OUTPUT OUT= desc.fail_chtrcd;
RUN;
/*
PROC EXPORT DATA= desc.fail_chtrcd
            OUTFILE= "C:\h1cpa01\work\Current Wheelock\Active\Bank Failures\Failures_Summary.xls" 
            DBMS=EXCEL REPLACE;
     SHEET="06failBnkchtrcd"; 
RUN;
*/


PROC MEANS data = fail.panel2006 n mean min max std q1 median q3;
  Title1 'Descriptive Stats of Failed Banks 2007-10 with Q2.2006 SOD Data by Specgrp';
  VAR asset depdom totbr tot_zipbr tot_cntybr tot_statebr ;
  CLASS specgrp;
  WHERE fail = 1;
  OUTPUT OUT= desc.fail_specgrp ;
RUN;
/*
PROC EXPORT DATA= desc.fail_specgrp
            OUTFILE= "C:\h1cpa01\work\Current Wheelock\Active\Bank Failures\Failures_Summary.xls" 
            DBMS=EXCEL REPLACE;
     SHEET="06FailBnkSpecgrp"; 
RUN;
*/

PROC MEANS data = fail.panel2006 n mean min max std q1 median q3;
  Title1 'Descriptive Stats of Non-Failed Banks 2007-10 with Q2.2006 SOD Data by Specgrp';
  VAR asset depdom totbr tot_zipbr tot_cntybr tot_statebr ;
  CLASS specgrp;
  WHERE fail ~= 1;
  OUTPUT OUT= desc.fail_specgrp ;
RUN;

/*
PROC EXPORT DATA= desc.fail_specgrp
            OUTFILE= "C:\h1cpa01\work\Current Wheelock\Active\Bank Failures\Failures_Summary.xls" 
            DBMS=EXCEL REPLACE;
     SHEET="06nofailBnkSpecgrp"; 
RUN;
*/


/*********************************************************************************************************/
/* Lets create summary statistics without Washington Mutual Bank (ID_RSSD 1222108) based on 2006 data.   */
/********************************************************************************************************/

/* Make a separate data set, so that we don't corrupt the full sample */ 
DATA work.panel2006_wamu;
  SET fail.panel2006;
  WHERE fail = 1;
  IF id_rssd in (1222108) THEN DELETE;
RUN;

PROC MEANS data = work.panel2006_wamu n mean min max std q1 median q3;
  Title1 'Descriptive Stats of Failed Banks 2007-10 with Q2.2006 SOD Data';
  Title2 'By Charter type code, excluding WaMu';
  VAR asset depdom totbr tot_zipbr tot_cntybr tot_statebr ;
  CLASS save;
  OUTPUT OUT= desc.fail_type_wamu;
RUN;
/*
PROC EXPORT DATA= desc.fail_type_wamu
            OUTFILE= "C:\h1cpa01\work\Current Wheelock\Active\Bank Failures\Failures_Summary.xls" 
            DBMS=EXCEL REPLACE;
     SHEET="06Failtypewamu"; 
RUN;
*/



/* The code below tests for the banks that failed in the 2007-09 period, but that did not exist in 2006:
    There were 10:

PROC CONTENTS data = fail.failures_2010;
RUN;

PROC CONTENTS data = work.sod2006_panel_fail;
RUN;



data work.sod2006_panel_fail_test;
  set work.sod2006_panel_fail;
  rename rssdid = id_rssd;
run;

proc sort data = work.sod2006_panel_fail_test;
  by id_rssd;
run;

DATA mergetest;
  MERGE fail.failures_2010 (IN= r_10) work.sod2006_panel_fail_test (IN = r_06);
  BY id_rssd;
  IF r_10 = 1 and r_06 = 0;
RUN; 


PROC PRINT data = mergetest;
RUN;


/* I'll leave the code in below, as a training exercise.  You'll note that callymd is simply a numeric variable,
    not a date variable.  To create a SAS date variable, you need to use the mdy() function and the substr fcn.
    BUT you also need to use the left() fcn to remove leading blanks.  Wow.  */
/*
DATA fail_sod2 (keep = callymd year dt_exist_term date);
  SET fail_sod;
  date = mdy(substr(trim(left(callymd)),5,2),substr(trim(left(callymd)),7,2),substr(trim(left(callymd)),1,4)) ;
  year = substr(trim(left(callymd)),1,4);
  FORMAT date date9.;
RUN;
*/
