/* Program written by Craig Aubuchon 
   April 20 2010

   Goal: To calculate the total number of commercial banks (charter type 200 and bank type analysis code = 0)
          in the year 1986Q2.  We'll use this as a baseline for the total number of banks in the different measures
          of charts - 

          
*/



OPTIONS LS = 75 PS = 60 NOCENTER PAGENO = 1 SYMBOLGEN MCOMPILENOTE = ALL MLOGIC;

/* A note on options: symbolgen specifies that log messages about macro variable references will be displayed
					  mcompilenote specifies that a note be completed for all macro compilations
					  mlogic specifies that messages about a macro action are printed to log during execution 
*/

LIBNAME fail            "C:\h1cpa01\work\Current Wheelock\Active\Bank Failures";

/* Assign variable labels to the select non-confidential variables from the Call Reports */

DATA totalbnks_1986_call;
  SET fail.totalbnks_1986_call;
  rename rcfd2170 = asset;
  label asset     = "Total Assets";
  label rcfd2200 = "Total Deposits";
  label rssd9210 = "State Code (FIPS)";
  label rssd9048 = "Charter Type Code";
  label rssd9050 = "FDIC Certification Number";
  label rssd9001 = "ID RSSD";
  label rssd9425 = "Bank Type Analysis Code";
RUN;

/* Clean out obvious mistakes - deposits greater than assets; negative deposits.  
    The code below removes 12 observations */

DATA totalbnks_1986_call;
  SET totalbnks_1986_call;
  where rcfd2170 > rcfd2200 OR rcfd220 > 0 OR rssd9210 > 56;
RUN;

/* Sort by ID_RSSD and then merge to failure data from NIC */

PROC SORT data = totalbnks_1986_call;
  by rssd9001;
RUN;

proc contents data = fail.failures_1992; /* There are 934 failures from 1987 to 1992 */
run;

DATA call_panel1986;
  MERGE totalbnks_1986_call (rename=(rssd9001=id_rssd) IN=restrict1986 ) fail.failures_1992;
  BY ID_RSSD;
  IF restrict1986 ;
  IF fail ~=1 THEN fail = 0;
RUN;

proc means data = call_panel1986 n;	/* There are 884 failures that were in existence in 1986Q2. */
  class fail;                       /* Thus, 50 banks were formed and failed in the 1987 to 1992 period */ 
run;

/* Now we have a panel of total deposits, total assets, and failures.
   Calculate totals by state for all banks and failed banks */

PROC SQL; 
  CREATE TABLE call_panel1986_2 as
  SELECT *, sum(rcfd2200) as tot_dep86_st, 
            sum(case when fail = 1 then rcfd2200 else 0 end) as tot_fail_dep86_st,
            /* Note the trick - I sum fail (since it equals 1 - this is like a count) bc a count will include the missing values */
			sum(case when fail = 1 then fail else 0 end) as nfail_1992,
			count(id_rssd) as totbnks_1986
  FROM call_panel1986
  GROUP BY rssd9210;
QUIT;

/* Make two data sets - one is the full panel of all data, which will be used for descriptive stats and density plots.
    The other contains information by state code, for making regular charts                                            */

DATA fail.map_panel1986; 
  SET work.call_panel1986_2;
  IF first.rssd9210;
  BY rssd9210;

DATA fail.map_panel1986 (keep = rssd9210 tot_dep86_st tot_fail_dep86_st nfail_1992 totbnks_1986 dep_failrt86 failrt_86);
  SET fail.map_panel1986;
  dep_failrt86 = (tot_fail_dep86_st / tot_dep86_st ) * 100;
   FORMAT dep_failrt86 3.2;
  failrt_86 = ( nfail_1992 / totbnks_1986 ) * 100;
   FORMAT  failrt_86 3.2;
RUN;

DATA fail.panel1986;
  SET work.call_panel1986_2;
RUN;
  
